@@ -132,49 +132,9 @@ impl Display for Error {
     }
 }
 
-/// The type used for operations.
-#[derive(Debug, Clone)]
-pub struct Number {
-    value: f64,
-}
-
-impl Number {
-    /// Create a new number from a value
-    pub fn new<N: Into<f64>>(n: N) -> Self {
-        Self {
-            value: n.into(),
-        }
-    }
-
-    /// invert the sign of the number
-    pub fn negate(&mut self) {
-        self.value = -self.value;
-    }
-
-    /// get the value of the number as an f64
-    pub fn as_f64(&self) -> f64 {
-        self.value
-    }
-
-    /// get the value of the number as an i128
-    pub fn as_i128(&self) -> i128 {
-        self.value.round() as i128
-    }
-}
-
-impl Display for Number {
-    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
-        write!(f, "{}", if self.value.fract() == 0.0 {
-            self.as_i128().to_string()
-        } else {
-            self.value.to_string()
-        })
-    }
-}
-
 /// A list of definitions to pass into the crate to be used in the interpreter.
 pub struct Definitions {
-    pub(crate) map: HashMap<String, Number>,
+    pub(crate) map: HashMap<String, f64>,
 }
 
 impl Definitions {
@@ -186,8 +146,8 @@ impl Definitions {
     }
 
     /// register a new definition to the map
-    pub fn register<S: Into<String>>(&mut self, name: S, value: Number) {
-        self.map.insert(name.into(), value);
+    pub fn register<S: Into<String>, N: Into<f64>>(&mut self, name: S, value: N) {
+        self.map.insert(name.into(), value.into());
     }
 
     pub fn exists<S: Into<String>>(&self, ident: S) -> bool {
@@ -195,14 +155,14 @@ impl Definitions {
     }
 
     /// Get a definition from the map
-    pub(crate) fn get<S: Into<String>>(&self, ident: S) -> Option<&Number> {
+    pub(crate) fn get<S: Into<String>>(&self, ident: S) -> Option<&f64> {
         self.map.get(ident.into().as_str())
     }
 }
 
 /// A list of definitions of functions to pass into the interpreter to solve for the variables.
 pub struct Functions<'a> {
-    pub(crate) functions: HashMap<String, Box<dyn Fn(Vec<Number>) -> Result<Number, Error> + 'a>>,
+    pub(crate) functions: HashMap<String, Box<dyn Fn(Vec<f64>) -> Result<f64, Error> + 'a>>,
 }
 
 impl<'a> Functions<'a> {
@@ -214,7 +174,7 @@ impl<'a> Functions<'a> {
     }
 
     /// register a function
-    pub fn register<S: Into<String>, F: Fn(Vec<Number>) -> Result<Number, Error> + 'a + Copy>(&mut self, name: S, f: F) {
+    pub fn register<S: Into<String>, F: Fn(Vec<f64>) -> Result<f64, Error> + 'a + Copy>(&mut self, name: S, f: F) {
         self.functions.insert(name.into(), Box::new(f));
     }
 
@@ -223,7 +183,7 @@ impl<'a> Functions<'a> {
         self.functions.contains_key(ident.into().as_str())
     }
 
-    pub(crate) fn get<S: Into<String>>(&self, ident: S) -> Option<&Box<dyn Fn(Vec<Number>) -> Result<Number, Error> + 'a>> {
+    pub(crate) fn get<S: Into<String>>(&self, ident: S) -> Option<&Box<dyn Fn(Vec<f64>) -> Result<f64, Error> + 'a>> {
         let ident = ident.into();
         if !self.functions.contains_key(&ident) {
             return None;
@@ -241,35 +201,35 @@ impl Default for Functions<'_> {
             if args.len() != 2 {
                 return Err(Error::arg_count("log", 2, args.len()));
             }
-            Ok(Number::new(args[1].as_f64().log(args[0].as_f64())))
+            Ok(args[1].log(args[0]))
         });
 
         funcs.register("sqrt", |args| {
             if args.len() != 1 {
                 return Err(Error::arg_count("sqrt", 1, args.len()));
             }
-            Ok(Number::new(args[0].as_f64().sqrt()))
+            Ok(args[0].sqrt())
         });
 
         funcs.register("sin", |args| {
             if args.len() != 1 {
                 return Err(Error::arg_count("sin", 1, args.len()));
             }
-            Ok(Number::new(args[0].as_f64().sin()))
+            Ok(args[0].sin())
         });
 
         funcs.register("cos", |args| {
             if args.len() != 1 {
                 return Err(Error::arg_count("cos", 1, args.len()));
             }
-            Ok(Number::new(args[0].as_f64().cos()))
+            Ok(args[0].cos())
         });
 
         funcs.register("tan", |args| {
             if args.len() != 1 {
                 return Err(Error::arg_count("tan", 1, args.len()));
             }
-            Ok(Number::new(args[0].as_f64().tan()))
+            Ok(args[0].tan())
         });
 
         funcs
@@ -284,11 +244,11 @@ impl Default for Functions<'_> {
 ///
 /// let solved = solve("(1 + 2) * 3");
 /// if solved.is_err() {
-///     panic!("{}", x.unwrap_err());
+///     panic!("{}", solved.unwrap_err());
 /// }
-/// assert_eq!(solved.unwrap().as_i128(), 9);
+/// assert_eq!(solved.unwrap() as i64, 9);
 /// ```
-pub fn solve<S: Into<String>>(input: S) -> Result<Number, Error> {
+pub fn solve<S: Into<String>>(input: S) -> Result<f64, Error> {
     let mut input = InputReader::new(input.into());
     let mut tokens = lex::lex(&mut input, false)?;
     let mut shunted = postfix::shunting_yard(&mut tokens)?;
@@ -302,40 +262,38 @@ pub fn solve<S: Into<String>>(input: S) -> Result<Number, Error> {
 ///
 /// # Usage Example:
 /// ```
-/// use calc_lib::{Definitions, Number, solve_defs};
+/// use calc_lib::{Definitions, solve_defs};
 ///
 /// let mut defs = Definitions::new();
-/// defs.register("x", Number::new(3));
+/// defs.register("x", 3);
 ///
 /// let solved = solve_defs("(x + 3) / 3", Some(&defs), None);
-/// assert_eq!(solved.unwrap().as_i128(), 2);
+/// assert_eq!(solved.unwrap() as i64, 2);
 /// ```
 ///
 /// # Usage with functions:
 /// ```
-/// use calc_lib::{Definitions, Functions, Number, solve_defs, Error};
+/// use calc_lib::{Definitions, Functions, solve_defs, Error};
 ///
 /// let mut defs = Definitions::new();
-/// defs.register("x", Number::new(3));
+/// defs.register("x", 3);
 ///
 /// let mut funcs = Functions::new();
 /// // this shows the definition of the log function,
 /// // which is already implemented in `Functions::default();`
 /// funcs.register("log", |args| {
-///     // this function takes two arguments, base and the number
 ///     if args.len() != 2 {
-///         // if the number of arguments is not 2, return an error
 ///         return Err(Error::arg_count("log", 2, args.len()));
 ///     }
-///     Ok(Number::new(args[1].as_f64().log(args[0].as_f64())))
-///  });
+///     Ok(args[1].log(args[0]))
+///});
 ///
 /// let solved = solve_defs("log(2, 16)", Some(&defs), Some(&funcs));
-/// assert_eq!(solved.unwrap().as_i128(), 4);
+/// assert_eq!(solved.unwrap() as i64, 4);
 /// ```
-pub fn solve_defs<S: Into<String>>(input: S, definitions: Option<&Definitions>, functions: Option<&Functions>) -> Result<Number, Error> {
+pub fn solve_defs<S: Into<String>>(input: S, definitions: Option<&Definitions>, functions: Option<&Functions>) -> Result<f64, Error> {
     let mut input = InputReader::new(input.into());
-    let mut tokens = lex::lex(&mut input, true)?;
+    let mut tokens = lex::lex(&mut input, definitions.is_some() || functions.is_some())?;
     let mut shunted = postfix::shunting_yard(&mut tokens)?;
     interpret_with_definitions(&mut shunted, definitions, functions)
 }
@@ -349,38 +307,38 @@ mod test {
         if solved.is_err() {
             panic!("{}", solved.err().unwrap());
         }
-        assert_eq!(solved.unwrap().as_i128(), 7);
+        assert_eq!(solved.unwrap() as i64, 7);
 
         let solved2 = solve("");
         if solved2.is_err() {
             panic!("{}", solved2.err().unwrap());
         }
-        assert_eq!(solved2.unwrap().as_i128(), 0);
+        assert_eq!(solved2.unwrap() as i64, 0);
 
         let x = solve("1.3 + 2.5 * 3.1");
         if x.is_err() {
             panic!("{}", x.unwrap_err());
         }
-        assert_eq!(x.unwrap().as_f64(), 9.05);
+        assert_eq!(x.unwrap(), 9.05);
 
         let mut defs = Definitions::new();
-        defs.register("x", Number::new(16));
+        defs.register("x", 16);
 
         let solved3 = solve_defs("(x + 4) / 5.0", Some(&defs), None);
-        assert_eq!(solved3.unwrap().as_f64(), 4.0);
+        assert_eq!(solved3.unwrap(), 4.0);
 
         let funcs = Functions::default();
         let solved4 = solve_defs("log(2, x)", Some(&defs), Some(&funcs));
         if solved4.is_err() {
             panic!("{}", solved4.unwrap_err());
         }
-        assert_eq!(solved4.unwrap().as_f64(), 4.0);
+        assert_eq!(solved4.unwrap(), 4.0);
 
         let solved5 = solve_defs("log(log(2,4), x)", Some(&defs), Some(&funcs));
         if solved5.is_err() {
             panic!("{}", solved5.unwrap_err());
         }
-        assert_eq!(solved5.unwrap().as_f64(), 4.0);
+        assert_eq!(solved5.unwrap(), 4.0);
     }
 
     #[test]
@@ -391,9 +349,9 @@ mod test {
             panic!("{}", solved_res.err().unwrap());
         }
         let solved = solved_res.unwrap();
-        assert_eq!(solved.clone().as_i128(), 16);
+        assert_eq!(solved.clone() as i128, 16);
 
         let mut defs = Definitions::new();
-        defs.register("solved", Number::new(solved.as_f64()));
+        defs.register("solved", solved);
     }
 }
\ No newline at end of file
